piiswrong closed pull request #10526: Minor spelling corrections in profile
URL: https://github.com/apache/incubator-mxnet/pull/10526
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/src/profiler/profiler.cc b/src/profiler/profiler.cc
index f2d14cf2729..974873bfba7 100644
--- a/src/profiler/profiler.cc
+++ b/src/profiler/profiler.cc
@@ -82,7 +82,7 @@ Profiler::Profiler()
   if (dmlc::GetEnv("MXNET_PROFILER_AUTOSTART", 0)) {
     this->state_ = ProfilerState::kRunning;
     this->enable_output_ = true;
-    // Since we want to avoid interfering with pure-VTune analylisys runs, for 
not set,
+    // Since we want to avoid interfering with pure-VTune analysis runs, for 
not set,
     // vtune will be recording based upon whether "Start" or "STart Paused" 
was selected
     vtune::vtune_resume();
   }
@@ -163,17 +163,17 @@ void Profiler::EmitPid(std::ostream *os, const 
std::string& name, size_t pid) {
         << "        }";
 }
 
-void Profiler::DumpProfile(bool peform_cleanup) {
+void Profiler::DumpProfile(bool perform_cleanup) {
   std::lock_guard<std::recursive_mutex> lock{this->m_};
   if (!IsEnableOutput()) {
     return;
   }
-  if (peform_cleanup) {
+  if (perform_cleanup) {
     SetContinuousProfileDump(false, 1.0f);
   }
   std::ofstream file;
   const bool first_pass = ++profile_dump_count_ == 1;
-  const bool last_pass = peform_cleanup || !continuous_dump_;
+  const bool last_pass = perform_cleanup || !continuous_dump_;
   if (!first_pass && continuous_dump_) {
     file.open(filename_, std::ios::app|std::ios::out);
   } else {
diff --git a/src/profiler/profiler.h b/src/profiler/profiler.h
index b8d0e8ef340..ed04d9e1452 100644
--- a/src/profiler/profiler.h
+++ b/src/profiler/profiler.h
@@ -299,9 +299,9 @@ class Profiler {
   }
   /*!
    * \brief dump the profile file
    * \param peform_cleanup Close off the json trace structures (ie last pass)
    */
-  void DumpProfile(bool peform_cleanup = true);
+  void DumpProfile(bool perform_cleanup = true);
 
   /*! \return the profiler init time, time unit is microsecond (10^-6) s */
   uint64_t MSHADOW_CINLINE GetInitTime() const {
@@ -477,7 +477,7 @@ class Profiler {
   /*! \brief Maintain in-memory aggregate stats for print output.
    *  \warning This has a negative performance impact */
   std::shared_ptr<AggregateStats> aggregate_stats_ = nullptr;
-  /*! \brief Asynchronous operation thread lifecycly control object */
+  /*! \brief Asynchronous operation thread lifecycle control object */
   std::shared_ptr<dmlc::ThreadGroup> thread_group_ = 
std::make_shared<dmlc::ThreadGroup>();
   /* !\brief pids */
   std::unordered_set<uint32_t> process_ids_;
@@ -555,7 +555,7 @@ struct ProfileDomain : public ProfileObject {
  */
 struct ProfileCounter : public ProfileObject {
   /*!
-   * \brief Co9nstructor
+   * \brief Constructor
    * \param name Counter name
    * \param domain Counter domain
    */


 

----------------------------------------------------------------
@@ -299,9 +299,9 @@ class Profiler {
   /*!
    * \brief dump the profile file
-   * \param peform_cleanup Close off the json trace structures (ie last pass)
+   * \param perform_cleanup Close off the json trace structures (ie last pass)
    */
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


With regards,
Apache Git Services

Reply via email to